/*
 * Designed and developed in 2022-2024 by William Walker (wnwalker@ucsc.edu)
 * Copyright 2022-2024 The Regents of the University of California. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import org.jetbrains.compose.desktop.application.dsl.TargetFormat

plugins {
    alias(libs.plugins.kotlinMultiplatform)
    alias(libs.plugins.kotlinxSerialization)
    alias(libs.plugins.composeCompiler)
    alias(libs.plugins.jetbrainsCompose)
    alias(libs.plugins.spotless)
}

kotlin {
    jvmToolchain(21)
    jvm()
    applyDefaultHierarchyTemplate()

    sourceSets {
        val commonMain by getting {
            dependencies {
                implementation(compose.ui)
                implementation(compose.runtime)
                implementation(compose.foundation)
                implementation(compose.material3)
                implementation(compose.materialIconsExtended)
                implementation(compose.components.resources)

                implementation(libs.koin.compose)
                implementation(libs.koin.composeVm)

                implementation(libs.jetbrains.navigation.compose)
                implementation(libs.androidx.lifecycle.compose)
                implementation(libs.androidx.lifecycle.viewmodel)

                implementation(project(":shared:shared"))

                implementation(libs.kmpWindowSizeClass)

//                implementation(libs.material3.adaptive)
//                implementation(libs.material3.adaptiveLayout)
//                implementation(libs.material3.adaptiveNavigation)

                implementation(libs.composeTheme)
                implementation(libs.composeTheme.material3)
//                implementation(libs.bundles.voyager)
                implementation(libs.dotenv.vault)
            }
        }
        val commonTest by getting {
            dependencies {
                @OptIn(org.jetbrains.compose.ExperimentalComposeLibrary::class)
                implementation(compose.uiTest)
            }
        }
        val jvmMain by getting {
            dependencies {
                implementation(compose.desktop.common)
                implementation(libs.appdirs)
            }
        }
        val jvmTest by getting {
            dependencies {
                implementation(compose.desktop.currentOs)
            }
        }
    }
}

composeCompiler {
    // Needed to enable Layout Inspector
    includeSourceInformation.set(true)
}

val appVersion = "1.0.0"
version = appVersion

//compose.desktop {
//
//    application {
//        mainClass = "MainKt"
//
//        // Required to build minified native distributions
//        buildTypes.release {
//            proguard {
//                version.set("7.4.2")
//                isEnabled.set(false)
//                optimize.set(false)
//            }
//        }
//
//        nativeDistributions {
//            includeAllModules = true
//            targetFormats(TargetFormat.Dmg, TargetFormat.Pkg, TargetFormat.Msi, TargetFormat.Exe, TargetFormat.Deb)
//
//            packageName = "Temerity"
//            description = "Temerity is a Kotlin Multiplatform library and desktop app for utilizing the YuJa Enterprise Video Platform API"
//            copyright = "© 2024 The Regents of the University of California. All rights reserved."
//            vendor = "ITS Division, University of California, Santa Cruz"
//            licenseFile.set(project.file("LICENSE"))
//            windows {
//                packageVersion = appVersion
//                exePackageVersion = appVersion
//                msiPackageVersion = appVersion
//
//                menu = true
//                // Allow Windows users to customize install location
//                dirChooser = true
//                perUserInstall = true
//            }
//            linux {
//                debMaintainer = "wnwalker@ucsc.edu"
//            }
//            macOS {
//                bundleID = "edu.ucsc.its.temerity.desktop"
//                dockName = "Temerity"
//                packageVersion = appVersion
//                dmgPackageVersion = appVersion
//                pkgPackageVersion = appVersion
//            }
//        }
//    }
//}

spotless {
    kotlin {
        target("**/*.kt")
        targetExclude("$buildDir/**/*.kt")
        ktlint().editorConfigOverride(
            mapOf(
                "indent_size" to "2",
                "continuation_indent_size" to "2"
            )
        )
        licenseHeaderFile(rootProject.file("spotless/appHeader.kt"))
        trimTrailingWhitespace()
        endWithNewline()
    }
    format("kts") {
        target("**/*.kts")
        targetExclude("$buildDir/**/*.kts")
        licenseHeaderFile(rootProject.file("spotless/appHeader.kt"), "(^(?![\\/ ]\\*).*$)")
        trimTrailingWhitespace()
        endWithNewline()
    }
}
