/*
 * Designed and developed in 2022-2024 by William Walker (wnwalker@ucsc.edu)
 * Copyright 2022-2024 The Regents of the University of California. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package edu.ucsc.its.temerity.shared.ui


import androidx.compose.runtime.Composable
import androidx.navigation.compose.NavHost
import androidx.navigation.compose.composable
import androidx.navigation.compose.rememberNavController
import androidx.navigation.createGraph
import edu.ucsc.its.temerity.shared.ui.elements.ListDetailLayoutWithSearchBar
import org.jetbrains.compose.resources.StringResource
import temerity.shared.compose.generated.resources.Res
import temerity.shared.compose.generated.resources.login
import temerity.shared.compose.generated.resources.main

/**
 * enum values to represent different root windows in the application
 */
enum class TemerityWindow(val title: StringResource) {
    Login(title = Res.string.login),
    Main(title = Res.string.main)
}

@Composable
fun RootScreen(){
    val navController = rememberNavController()
    val navGraph = navController.createGraph(
        startDestination = TemerityWindow.Login.name
    ) {
        composable(TemerityWindow.Login.name) {
            LoginScreen(onLogin = {
                navController.navigate(TemerityWindow.Main.name)
            })
        }
        composable(TemerityWindow.Main.name) {
            MainScreen()
        }
    }

    NavHost(
        navController = navController,
        graph = navGraph
    )
}

@Composable
fun MainScreen() {
    ListDetailLayoutWithSearchBar()
}