package edu.ucsc.its.temerity.shared.data.repository

/*
 * Designed and developed in 2022-2024 by William Walker (wnwalker@ucsc.edu)
 * Copyright 2022-2024 The Regents of the University of California. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import androidx.compose.runtime.mutableLongStateOf
import co.touchlab.kermit.Logger
import edu.ucsc.its.temerity.PlatformClient
import edu.ucsc.its.temerity.remote.Device
import edu.ucsc.its.temerity.remote.Group
import edu.ucsc.its.temerity.remote.User
import edu.ucsc.its.temerity.shared.AppSettings
import edu.ucsc.its.temerity.shared.data.repository.PlatformRepositoryInterface.CacheFlag
import edu.ucsc.its.temerity.shared.data.repository.PlatformRepositoryInterface.CacheFlag.DISABLE
import edu.ucsc.its.temerity.shared.database.AppDatabase
import kotlinx.coroutines.CoroutineScope
import kotlinx.coroutines.Dispatchers
import kotlinx.coroutines.Job
import kotlinx.coroutines.launch
import org.koin.core.component.KoinComponent
import org.koin.core.component.get
import org.koin.core.component.inject
import org.koin.core.parameter.parametersOf

interface PlatformRepositoryInterface {

    sealed class CacheFlag(val enable: Boolean) {
        data object ENABLE: CacheFlag(true)
        data object DISABLE: CacheFlag(false)
    }

    suspend fun fetchGroups(flag: CacheFlag = DISABLE): List<Group>
    suspend fun fetchUsers(flag: CacheFlag = DISABLE): List<User>
    suspend fun fetchDevices(flag: CacheFlag = DISABLE): List<Device>
}

class PlatformRepository : KoinComponent, PlatformRepositoryInterface {
    private lateinit var platformClient: PlatformClient
    private val database : AppDatabase by inject()
    private val appSettings: AppSettings by inject()

    private val jobScope = CoroutineScope(Dispatchers.IO + Job())
    var updateInterval = mutableLongStateOf(-1L)

    val logger = Logger.withTag("PlatformRepository")

    init {
        jobScope.launch {
            loadDataForAppStart()
        }
    }

    private suspend fun updateServiceEndpoint(newEndpointUrl: String) {
        appSettings.updateServiceEndpoint(newEndpointUrl)
        platformClient = get { parametersOf(appSettings.userServiceEndpoint, appSettings.userAuthToken) }
        // TODO: Test new PC here
    }

    private suspend fun updateUserAuthToken(newToken: String) {
        appSettings.updateUserAuthToken(newToken)
        platformClient = get { parametersOf(appSettings.userServiceEndpoint, appSettings.userAuthToken) }
        // TODO: Test new PC here
    }

    private suspend fun loadDataForAppStart() {

    }

    override suspend fun fetchGroups(flag: CacheFlag): List<Group> {
        TODO("Not yet implemented")
    }

    override suspend fun fetchUsers(flag: CacheFlag): List<User> {
        TODO("Not yet implemented")
    }

    override suspend fun fetchDevices(flag: CacheFlag): List<Device> {
        TODO("Not yet implemented")
    }
}
