/*
 *     Designed and developed in 2022-2024 by William Walker (wnwalker@ucsc.edu)
 *     Copyright 2022-2024 The Regents of the University of California. All rights reserved.
 *
 *     This library is free software; you can redistribute it and/or
 *     modify it under the terms of the GNU Lesser General Public
 *     License as published by the Free Software Foundation; version 2.1 of the License.
 *
 *     This library is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *     Lesser General Public License for more details.
 *
 *     You should have received a copy of the GNU Lesser General Public
 *     License along with this library; if not, write to the Free Software
 *     Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
package edu.ucsc.its.temerity

import edu.ucsc.its.temerity.di.libModule
import org.koin.dsl.koinApplication


/**
 * TemerityLibraryKoinContext is the main entry point for the Temerity library.
 *
 * This object is used to initialize the Koin dependency injection framework
 *
 */
internal object TemerityLibraryKoinContext {
  internal const val TIMEOUT = 3000L

  private val koinApp = koinApplication {
    modules(libModule)
  }
  internal val koin = koinApp.koin
}

/**
 * Create a PlatformClient instance using Kotlin-DSL.
 */
public fun platformClient(builder: PlatformClient.Builder.() -> Unit): PlatformClient =
  TemerityLibraryKoinContext.koin.get<PlatformClient.Builder>().apply(builder).build()

/**
 * Creates a PlatformClient.Builder instance using Kotlin-DSL.
 */
public fun platformClientBuilder(builder: PlatformClient.Builder.() -> Unit): PlatformClient.Builder =
  TemerityLibraryKoinContext.koin.get<PlatformClient.Builder>().apply(builder)
